Одеський Національний технологічний університет

## Розклад навчальних занять

Сьогодні: 17 вересня 2022р. ()
Розклад перескладань доступний за посиланням "Розклад перескладань"

- 0

##### Розклад на поточний тиждень

День | Пара | КН-321
--- | --- | ---
а
# П о н е д і л о к | ## 1 |
## 2 |
## 3 |
## 4 | ТА (Онлайн лаб.) Владімірова В. Б. Ідентифікатор/Код Ідентифікатор конференції: 714 1621 3997 Код доступу: mi7s8r
## 5 | ТА (Онлайн лаб.) Владімірова В. Б. Ідентифікатор/Код Ідентифікатор конференції: 714 1621 3997 Код доступу: mi7s8r
## 6 |
# В і в т о р о к | ## 1 |
## 2 |
## 3 | Ін. мова (Онлайн практ.) Вереітіна І. А. Ідентифікатор/Код Идентификатор конференции: 352 306 6371 Код доступа: 6cELPd
## 4 | Ін. мова (Онлайн практ.) Вереітіна І. А. Ідентифікатор/Код Идентификатор конференции: 352 306 6371 Код доступа: 6cELPd
## 5 |
## 6 |
# С е р е д а | ## 1 | МЗКІТ (Онлайн лаб.) Снігур Т. С. Ідентифікатор/Код Ідентифікатор конференції: 733 1774 9597 Код доступу: nXfx2h
## 2 |
## 3 | ФВ (Онлайн практ.) Цапенко Л. М. Ідентифікатор/Код Ідентифікатор: 738 465 7117 Пароль: 3733
## 4 |
## 5 |
## 6 |
# Ч е т в е р | ## 1 |
## 2 |
## 3 |
## 4 | КСТ АКтаКМ (Онлайн лаб.) Жирнова Т. М. Ідентифікатор/Код Татьяна Жирнова приглашает вас на запланированную конференцию: Zoom. Тема: Зал персональной конференции Татьяна Жирнова Подключиться к конференции Zoom https://zoom.us/j/2024082822?pwd=Z0lQYjVnVjdham5nc1VlZlg5a0NBQT09 Идентификатор конференции: 202 408 2822 Код доступа: 5AfUGy
## 5 |
## 6 |
# П ` я т н и ц я | ## 1 |
## 2 |
## 3 |
## 4 |
## 5 |
## 6 |
# С у б о т а | ## 1 |
## 2 |
## 3 |
## 4 |
## 5 |
## 6 |

##### Розклад екзаменів та перескладань

##### Оголошення

##### Файли